Internal accessor for palette_list data, compatible with both installed package and devtools::load_all() development mode.
Source:R/04-palettes.R
dot-get_palette_list.RdInternal accessor for palette_list data, compatible with both installed package and devtools::load_all() development mode.